@@ -13,7 +13,4 @@ def main():
 	for t in tops:
 		t.show()
 
-
-if __name__ == "__main__":
-	main()
-
+#main()
